@@ -22,13 +22,6 @@
 #include <config.h>
 #endif
 
-#include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <gconf/gconf-client.h>
-#include "egg-recent-model.h"
-#include "egg-recent-item.h"
-
 #include <stdio.h>
 #include <string.h>
 #include <errno.h>
@@ -37,7 +30,12 @@
 #include <fcntl.h>
 #include <sys/time.h>
 #include <time.h>
-
+#include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+#include <gconf/gconf-client.h>
+#include "egg-recent-model.h"
+#include "egg-recent-item.h"
 
 #define EGG_RECENT_MODEL_FILE_PATH "/.recently-used"
 #define EGG_RECENT_MODEL_BUFFER_SIZE 8192
@@ -107,7 +105,6 @@ typedef enum {
 	STATE_MIME_TYPE,
 	STATE_TIMESTAMP,
 	STATE_PRIVATE,
-	STATE_COUNT,
 	STATE_GROUPS,
 	STATE_GROUP
 } ParseState;
@@ -123,7 +120,6 @@ typedef struct _ChangedData {
 #define TAG_MIME_TYPE "Mime-Type"
 #define TAG_TIMESTAMP "Timestamp"
 #define TAG_PRIVATE "Private"
-#define TAG_COUNT "Count"
 #define TAG_GROUPS "Groups"
 #define TAG_GROUP "Group"
 
@@ -266,7 +262,7 @@ egg_recent_model_update_item (GList *items, EggRecentItem *upd_item)
 
 		if (gnome_vfs_uris_match (egg_recent_item_peek_uri (item), uri)) {
 			egg_recent_item_set_timestamp (item, (time_t) -1);
-			egg_recent_item_set_count (item, egg_recent_item_get_count (item) + 1);
+
 			egg_recent_model_add_new_groups (item, upd_item);
 
 			return TRUE;
@@ -362,8 +358,6 @@ start_element_handler (GMarkupParseContext *context,
 		egg_recent_item_set_private (info->current_item, TRUE);
 	} else if (ELEMENT_IS (TAG_GROUPS))
 		push_state (info, STATE_GROUPS);
-	else if (ELEMENT_IS (TAG_COUNT))
-		push_state (info, STATE_COUNT);
 	else if (ELEMENT_IS (TAG_GROUP)) 
 		push_state (info, STATE_GROUP);
 }
@@ -386,24 +380,6 @@ list_compare_func_lru (gpointer a, gpointer b)
 	return item_a->timestamp > item_b->timestamp;
 }
 
-static gint
-list_compare_func_lfu (gpointer a, gpointer b)
-{
-	EggRecentItem *item_a = (EggRecentItem *)a;
-	EggRecentItem *item_b = (EggRecentItem *)b;
-
-	return item_a->count > item_b->count;
-}
-
-static gint
-list_compare_func_mfu (gpointer a, gpointer b)
-{
-	EggRecentItem *item_a = (EggRecentItem *)a;
-	EggRecentItem *item_b = (EggRecentItem *)b;
-
-	return item_a->count < item_b->count;
-}
-
 
 
 static void
@@ -416,6 +392,11 @@ end_element_handler (GMarkupParseContext *context,
 
 	switch (peek_state (info)) {
 		case STATE_RECENT_ITEM:
+			if ((info->current_item->mime_type == NULL) &&
+			    !info->current_item->mime_type_is_explicit)
+			{
+				egg_recent_item_set_mime_type (info->current_item, NULL);
+			}
 			info->items = g_list_append (info->items,
 						    info->current_item);
 			if (info->current_item->uri == NULL ||
@@ -446,7 +427,17 @@ text_handler (GMarkupParseContext *context,
 		case STATE_GROUPS:
 		break;
 		case STATE_URI:
-			egg_recent_item_set_uri (info->current_item, text);
+		{
+			if ((info->current_item->mime_type == NULL) &&
+			    !info->current_item->mime_type_is_explicit)
+			{
+				info->current_item->mime_type_is_explicit = TRUE;
+				egg_recent_item_set_uri (info->current_item, text);
+				info->current_item->mime_type_is_explicit = FALSE;
+			}
+			else
+				egg_recent_item_set_uri (info->current_item, text);
+		}
 		break;
 		case STATE_MIME_TYPE:
 			egg_recent_item_set_mime_type (info->current_item,
@@ -456,10 +447,6 @@ text_handler (GMarkupParseContext *context,
 			egg_recent_item_set_timestamp (info->current_item,
 							 (time_t)atoi (text));
 		break;
-		case STATE_COUNT:
-			egg_recent_item_set_count (info->current_item,
-							 (time_t)atoi (text));
-		break;
 		case STATE_GROUP:
 			egg_recent_item_add_group (info->current_item,
 						     text);
@@ -512,14 +499,6 @@ egg_recent_model_sort (EggRecentModel *model, GList *list)
 			list = g_list_sort (list,
 					(GCompareFunc)list_compare_func_lru);
 		break;
-		case EGG_RECENT_MODEL_SORT_MFU:
-			list = g_list_sort (list,
-					(GCompareFunc)list_compare_func_mfu);
-		break;
-		case EGG_RECENT_MODEL_SORT_LFU:
-			list = g_list_sort (list,
-					(GCompareFunc)list_compare_func_lfu);
-		break;
 		case EGG_RECENT_MODEL_SORT_NONE:
 		break;
 	}
@@ -816,7 +795,6 @@ egg_recent_model_write (EggRecentModel *model, FILE *file, GList *list)
 		gchar *mime_type;
 		gchar *escaped_uri;
 		time_t timestamp;
-		int count;
 		item = (EggRecentItem *)list->data;
 
 
@@ -827,8 +805,7 @@ egg_recent_model_write (EggRecentModel *model, FILE *file, GList *list)
 
 		mime_type = egg_recent_item_get_mime_type (item);
 		timestamp = egg_recent_item_get_timestamp (item);
-		count = egg_recent_item_get_count (item);
-
+		
 		string = g_string_append (string, "  <" TAG_RECENT_ITEM ">\n");
 
 		g_string_append_printf (string,
@@ -845,9 +822,6 @@ egg_recent_model_write (EggRecentModel *model, FILE *file, GList *list)
 		g_string_append_printf (string,
 				"    <" TAG_TIMESTAMP ">%d</" TAG_TIMESTAMP ">\n", (int)timestamp);
 
-		g_string_append_printf (string,
-				"    <" TAG_COUNT ">%d</" TAG_COUNT ">\n", count);
-
 		if (egg_recent_item_get_private (item))
 			string = g_string_append (string,
 					"    <" TAG_PRIVATE "/>\n");
